@@ -100,6 +100,8 @@ impl State {
 
     pub fn update(&mut self, term: &mut Term, events: &[GituEvent]) -> Res<()> {
         for event in events {
+            log::debug!("{:?}", event);
+
             match *event {
                 GituEvent::Term(Event::Resize(w, h)) => {
                     for screen in self.screens.iter_mut() {
@@ -320,7 +322,7 @@ impl State {
         let child = cmd.spawn()?;
 
         let out = child.wait_with_output()?;
-        let out_utf8 = String::from_utf8(out.stderr.clone())
+        let out_utf8 = String::from_utf8(strip_ansi_escapes::strip(out.stderr.clone()))
             .expect("Error turning command output to String")
             .into();
 
